@@ -11,7 +11,7 @@
 import asyncio
 import logging
 
-from typing import Optional, Sequence, Tuple, List
+from typing import Optional, Sequence, List
 
 # -------------------
 # Third party imports
@@ -27,7 +27,7 @@ from tessdbdao.asyncio import Location
 # -------------
 
 from ..util import Session
-from ..model import LocationInfo, GEO_COORD_EPSILON as EPSILON
+from ..model import LocationInfo, LogSpace, GEO_COORD_EPSILON as EPSILON
 from ..location_common import geolocate, distance
 
 # ----------------
@@ -35,7 +35,7 @@ from ..location_common import geolocate, distance
 # ----------------
 
 
-log = logging.getLogger(__name__.split(".")[-1])
+log = logging.getLogger(LogSpace.DBASE)
 
 # -------------
 # API functions
