@@ -11,15 +11,12 @@
 import logging
 from typing import Optional
 from datetime import datetime
+from dataclasses import dataclass
 
 # -------------------
 # Third party imports
 # -------------------
 
-from pubsub import pub
-
-
-# from typing_extensions import Self
 from sqlalchemy import func, select, update
 from tessdbdao import (
     ObserverType,
@@ -35,23 +32,56 @@ from tessdbdao.asyncio import Location, Observer, NameMapping, Tess, TessReading
 # -------------
 
 from ...util import Session, async_lru_cache
-from ...model import (
-    PhotometerInfo,
-    RegisterOp,
-    RegisterEvent,
-    INFINITE_T,
-    LogSpace
-)
+from ...model import PhotometerInfo, INFINITE_T, LogSpace
 
 ZP_EPS = 0.005
 FREQ_EPS = 0.001
 
 
+@dataclass(slots=True)
+class Stats:
+    num_registered: int = 0
+    num_zp_changed: int = 0
+    num_created: int = 0
+    num_renamed: int = 0
+    num_replaced: int = 0
+    num_rebooted: int = 0
+    num_extinct: int = 0
+
+    def reset(self) -> None:
+        """Resets stat counters"""
+        self.num_registered = 0
+        self.num_zp_changed = 0
+        self.num_created = 0
+        self.num_renamed = 0
+        self.num_replaced = 0
+        self.num_rebooted = 0
+        self.num_extinct = 0
+
+    def show(self) -> None:
+        log.info(
+            "DBASE Register Stats [Register, Created, Renamed, Replaced, Extinct, Rebooted, ZP-Changed] = %s",
+            [
+                self.num_registered,
+                self.num_created,
+                self.num_renamed,
+                self.num_replaced,
+                self.num_extinct,
+                self.num_rebooted,
+                self.num_zp_changed,
+            ],
+        )
+
+
 # ----------------
 # Global variables
 # ----------------
 
+ZP_EPS = 0.005
+FREQ_EPS = 0.001
+
 log = logging.getLogger(LogSpace.DBASE)
+stats = Stats()
 
 # ===================================
 # Registry process auxiliar functions
@@ -257,8 +287,7 @@ async def replacing_photometer(
         plog.debug("Replacing back %s", dict(candidate))
         updated = maybe_update_managed_attributes(session, candidate, another_tess)
         if updated:
-            # self.nZPChange += 1
-            pub.sendMessage(RegisterEvent.ZP_CHANGE, source=source)
+            stats.num_zp_changed += 1
 
     else:
         # Copy the observer and location from the broken photometer
@@ -472,6 +501,7 @@ async def photometer_register(
     source: ReadingSource = ReadingSource.DIRECT,
     dry_run: bool = False,
 ) -> None:
+    stats.num_registered += 1
     plog = logging.getLogger(candidate.name)
     old_mac_entry = await lookup_mac(session, candidate.mac_address)
     old_name_entry = await lookup_name(session, candidate.name)
@@ -480,9 +510,7 @@ async def photometer_register(
         # Brand new TESS-W case:
         # No existitng (MAC, name) pairs in the name_to_mac_t table
         await add_brand_new_tess(session, candidate, observer_type, observer_name, place)
-        # STATS CODE
-        # self.nCreation += 1
-        pub.sendMessage(RegisterOp.CREATE, source=source)
+        stats.num_created += 1
         log.info(
             "Brand new photometer registered: %s (MAC = %s)",
             candidate.name,
@@ -497,10 +525,8 @@ async def photometer_register(
         # A clean rename with no collision
         # A (MAC, name) exists in the name_to_mac_t table with the MAC given by the candidate
         # but the name in the candidate does not.
-        # STATS CODE
-        # self.nRename += 1
+        stats.num_renamed += 1
         await renaming_photometer(session, old_mac_entry, candidate)
-        pub.sendMessage(RegisterOp.RENAME, source=source)
         log.info(
             "Renamed photometer %s (MAC = %s) with brand new name %s",
             old_mac_entry.name,
@@ -518,10 +544,8 @@ async def photometer_register(
         # A (MAC, name) pair exist in the name_to_mac_t table with the same name as the candidate
         # but the MAC in the candiate is new.
         # This means that we are probably replacing a broken photometer with a new one, keeping the same name.
-        # STATS CODE
-        # self.nReplace += 1
+        stats.num_replaced += 1
         await replacing_photometer(session, old_name_entry, candidate, source)
-        pub.sendMessage(RegisterOp.REPLACE, source=source)
         log.info(
             "Replaced photometer tagged %s (old MAC = %s) with new one with MAC %s",
             old_name_entry.name,
@@ -546,11 +570,9 @@ async def photometer_register(
             photometer = await find_photometer_by_name(session, candidate.name)
             updated = maybe_update_managed_attributes(session, candidate, photometer)
             if updated:
-                # self.nZPChange += 1
-                pub.sendMessage(RegisterEvent.ZP_CHANGE, source=source)
+                stats.num_zp_changed += 1
             else:
-                # self.nReboot += 1
-                pub.sendMessage(RegisterEvent.PHOT_RESET, source=source)
+                stats.num_rebooted += 1
                 log.info(
                     "Detected reboot for photometer %s (MAC = %s)",
                     candidate.name,
@@ -568,7 +590,7 @@ async def photometer_register(
             )
             log.info("Label %s has no associated photometer now!", old_mac_entry.name)
             await override_associations(session, old_mac_entry, old_name_entry, candidate)
-            pub.sendMessage(RegisterOp.EXTINCT, source=source)
+            stats.num_extinct += 1
 
     if dry_run:
         log.info("Dry run mode. Database not written")
