@@ -10,6 +10,7 @@
 
 import logging
 from datetime import datetime
+from dataclasses import dataclass
 from typing import Optional, Tuple, Iterable, Sequence, List, Union
 from functools import lru_cache
 
@@ -17,8 +18,6 @@ from functools import lru_cache
 # Third party imports
 # -------------------
 
-from pubsub import pub
-
 
 # from typing_extensions import Self
 from sqlalchemy import select, and_
@@ -41,12 +40,41 @@ from ...model import (
     ReadingInfo1c,
     ReadingInfo4c,
     ReadingInfo,
-    ReadingEvent,
     LogSpace,
     IMPOSSIBLE_SIGNAL_STRENGTH,
     IMPOSSIBLE_TEMPERATURE,
 )
 
+
+@dataclass(slots=True)
+class Stats:
+    num_readings: int = 0
+    rej_not_registered: int = 0
+    rej_hash_mismatch: int = 0
+    rej_not_authorised: int = 0
+    rej_duplicated: int = 0
+
+    def reset(self) -> None:
+        """Resets stat counters"""
+        self.num_readings = 0
+        self.rej_not_registered = 0
+        self.rej_hash_mismatch = 0
+        self.rej_not_authorised = 0
+        self.rej_duplicated = 0
+
+    def show(self) -> None:
+        log.info(
+            "DBASE Readings Stats [Readings, NotRegistered, HashMismatch, NotAuthorised, Duplicated] = %s",
+            [
+                self.num_readings,
+                self.rej_not_registered,
+                self.rej_hash_mismatch,
+                self.rej_not_authorised,
+                self.rej_duplicated,
+            ],
+        )
+
+
 # ----------------
 # Global variables
 # ----------------
@@ -54,6 +82,7 @@ from ...model import (
 PhotReadings = Union[TessReadings, Tess4cReadings]
 
 log = logging.getLogger(LogSpace.DBASE)
+stats = Stats()
 
 # ===================================
 # Registry process auxiliar functions
@@ -130,13 +159,13 @@ def resolve_references(
     latest: bool,
     source: ReadingSource,
 ) -> Optional[ReferencesInfo]:
+    stats.num_readings += 1
     plog = logging.getLogger(reading.name)
-    pub.sendMessage(ReadingEvent.WRITE_REQUEST, source=source)
     units_id = resolve_units_id(session, source, reading.tstamp_src)
     try:
         phot = find_photometer_by_name(session, reading.name, reading.hash, reading.tstamp, latest)
         if phot is None:
-            pub.sendMessage(ReadingEvent.NOT_REGISTERED, source=source)
+            stats.rej_not_registered += 1
             log.info(
                 "No TESS %s registered ! => %s",
                 reading.name,
@@ -149,7 +178,7 @@ def resolve_references(
             )
             return None
     except HashMismatchError as e:
-        pub.sendMessage(ReadingEvent.HASH_MISMATCH, source=source)
+        stats.rej_hash_mismatch += 1
         log.info(
             "[%s] Reading rejected by hash mismatch: %s => %s", reading.name, str(e), dict(reading)
         )
@@ -159,7 +188,7 @@ def resolve_references(
         return None
     else:
         if auth_filter and not phot.authorised:
-            pub.sendMessage(ReadingEvent.NOT_AUTHORISED, source=source)
+            stats.rej_not_authorised += 1
             log.info("[%s]: Not authorised: %s", reading.name, dict(reading))
             plog.debug("[%s]: Not authorised: %s", reading.name, dict(reading))
             return None
@@ -275,11 +304,9 @@ def _photometer_looped_write(
                 session.commit()
             except Exception:
                 rej += 1
-                pub.sendMessage(ReadingEvent.SQL_ERROR, source=source)
+                stats.rej_duplicated += 1
                 log.warning("Discarding reading by SQL Integrity error: %s", dict(items[i][0]))
                 session.rollback()
-            else:
-                pub.sendMessage(ReadingEvent.SQL_OK, source=source, count=1)
     log.info("Rejected [%d/%d] database writes in loop", rej, N)
 
 
@@ -320,7 +347,6 @@ def photometer_batch_write(
             session.close()
             _photometer_looped_write(session, objs, items, source)
         else:
-            pub.sendMessage(ReadingEvent.SQL_OK, source=source, count=len(objs))
             session.close()
 
 
@@ -346,5 +372,4 @@ def photometer_resolved_batch_write(
             session.close()
             _photometer_looped_write(session, objs, items, source)
         else:
-            pub.sendMessage(ReadingEvent.SQL_OK, source=source, count=len(objs))
             session.close()
